/*!
 * Copyright (c) Microsoft Corporation. All rights reserved.
 * Licensed under the MIT License.
 */
import { SharedString } from "@fluidframework/sequence";
import React from "react";
export interface ICollaborativeInputProps {
    /**
     * The SharedString that will store the input value.
     */
    sharedString: SharedString;
    /**
     * Whether spellCheck should be enabled.  Defaults to true.
     */
    spellCheck?: boolean;
    className?: string;
    style?: React.CSSProperties;
    onInput?: (sharedString: SharedString) => void;
}
export interface ICollaborativeInputState {
    selectionEnd: number;
    selectionStart: number;
}
/**
 * Given a SharedString will produce a collaborative input element.
 */
export declare class CollaborativeInput extends React.Component<ICollaborativeInputProps, ICollaborativeInputState> {
    private readonly inputElementRef;
    constructor(props: ICollaborativeInputProps);
    componentDidMount(): void;
    componentDidUpdate(prevProps: ICollaborativeInputProps): void;
    render(): JSX.Element;
    private updateInputFromSharedString;
    private handleInput;
    /**
     * Update the current caret selection.
     * We need to do this before we do any handleInput action or we will have lost our
     * cursor position and not be able to accurately update the shared string.
     */
    private updateSelection;
}
//# sourceMappingURL=CollaborativeInput.d.ts.map